#!/usr/bin/env bash
set -euo pipefail

echo "Starting MSSQL docker container..."
MSSQL_PASSWORD="Hair-Exist-Large-Guess-1"
MSSQL_CONTAINER="mssql_extract_stats"
docker run --name "$MSSQL_CONTAINER" \
  -v "$(pwd)"/tpch:/tpch \
  -e 'ACCEPT_EULA=Y' -e "SA_PASSWORD=$MSSQL_PASSWORD" \
  -d mcr.microsoft.com/mssql/server:2019-latest

# Wait a bit until the server accepts connections
sleep 5

echo "Loading TPC-H schema..."
docker exec "$MSSQL_CONTAINER" /opt/mssql-tools/bin/sqlcmd \
  -S localhost -U sa -P "$MSSQL_PASSWORD" \
  -Q "$(cat tpch/schema.sql tpch/schema2.sql)"

echo "Loading TPC-H tables..."
docker exec "$MSSQL_CONTAINER" /opt/mssql-tools/bin/sqlcmd \
  -S localhost -U sa -P "$MSSQL_PASSWORD" \
  -Q "BULK INSERT customer        FROM '/tpch/customer.tbl'        WITH (FIELDTERMINATOR='|', ROWTERMINATOR='\n');"
docker exec "$MSSQL_CONTAINER" /opt/mssql-tools/bin/sqlcmd \
  -S localhost -U sa -P "$MSSQL_PASSWORD" \
  -Q "BULK INSERT lineitem        FROM '/tpch/lineitem.tbl'        WITH (FIELDTERMINATOR='|', ROWTERMINATOR='\n');"
docker exec "$MSSQL_CONTAINER" /opt/mssql-tools/bin/sqlcmd \
  -S localhost -U sa -P "$MSSQL_PASSWORD" \
  -Q "BULK INSERT custom_lineitem FROM '/tpch/lineitem.tbl'        WITH (FIELDTERMINATOR='|', ROWTERMINATOR='\n');"
docker exec "$MSSQL_CONTAINER" /opt/mssql-tools/bin/sqlcmd \
  -S localhost -U sa -P "$MSSQL_PASSWORD" \
  -Q "BULK INSERT nation          FROM '/tpch/nation.tbl'          WITH (FIELDTERMINATOR='|', ROWTERMINATOR='\n');"
docker exec "$MSSQL_CONTAINER" /opt/mssql-tools/bin/sqlcmd \
  -S localhost -U sa -P "$MSSQL_PASSWORD" \
  -Q "BULK INSERT orders          FROM '/tpch/orders.tbl'          WITH (FIELDTERMINATOR='|', ROWTERMINATOR='\n');"
docker exec "$MSSQL_CONTAINER" /opt/mssql-tools/bin/sqlcmd \
  -S localhost -U sa -P "$MSSQL_PASSWORD" \
  -Q "BULK INSERT part            FROM '/tpch/part.tbl'            WITH (FIELDTERMINATOR='|', ROWTERMINATOR='\n');"
docker exec "$MSSQL_CONTAINER" /opt/mssql-tools/bin/sqlcmd \
  -S localhost -U sa -P "$MSSQL_PASSWORD" \
  -Q "BULK INSERT partsupp        FROM '/tpch/partsupp.tbl'        WITH (FIELDTERMINATOR='|', ROWTERMINATOR='\n');"
docker exec "$MSSQL_CONTAINER" /opt/mssql-tools/bin/sqlcmd \
  -S localhost -U sa -P "$MSSQL_PASSWORD" \
  -Q "BULK INSERT supplier        FROM '/tpch/supplier.tbl'        WITH (FIELDTERMINATOR='|', ROWTERMINATOR='\n');"
docker exec "$MSSQL_CONTAINER" /opt/mssql-tools/bin/sqlcmd \
  -S localhost -U sa -P "$MSSQL_PASSWORD" \
  -Q "BULK INSERT region          FROM '/tpch/region.tbl'          WITH (FIELDTERMINATOR='|', ROWTERMINATOR='\n');"

echo "Cleaning up, removing docker container again"
docker stop "$MSSQL_CONTAINER"
docker rm "$MSSQL_CONTAINER"
